==> haskell-ansi-terminal-types-0.11.5-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-9Oiu8AjaKQ98gM9Y0qLF8b
key:                  ansi-terminal-types-0.11.5-9Oiu8AjaKQ98gM9Y0qLF8b
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  5d1ef5a1a874ccc9f89603cdd6189c0a
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-9Oiu8AjaKQ98gM9Y0qLF8b
depends:              base-4.17.2.1 colour-2.3.6-Fuw3AbFioIZ9repUO0m0MS
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-types-0.11.5-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-6BO5tZdDL8E4pivz6UUHu5
key:                  ansi-terminal-types-0.11.5-6BO5tZdDL8E4pivz6UUHu5
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  4d65f98015eea5c04a298edea188ce76
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-6BO5tZdDL8E4pivz6UUHu5
depends:              base-4.17.2.1 colour-2.3.6-3QM3ySa5D7w9XJQn2r8k6I
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
